@@ -214,7 +214,7 @@ sub apply_TableSpec_config {
 	$self->TableSpec or return;
 	$self->TableSpec_applied and return;
 	
-	my $prop_names = [ @RapidApp::Column::attrs ];
+	my $prop_names = [ @RapidApp::Module::DatStor::Column::attrs ];
 	my $columns = $self->TableSpec->columns_properties_limited($prop_names);
 	
 	$self->apply_columns($columns);
@@ -265,6 +265,7 @@ has 'add_edit_formpanel_defaults', is => 'ro', isa => 'HashRef', lazy => 1, defa
 	labelWidth => 100,
 	plugins => ['dynamic-label-width'],
 	bodyStyle => 'padding: 25px 10px 5px 5px;',
+  cls => 'ra-datastore-add-edit-form',
 	defaults => {
 		width => 250
 	},
@@ -340,6 +341,14 @@ sub get_add_edit_form_items {
     # set with allowBlank: false (common-sense failsafe):
     $field->{allowBlank} = \1 if (jstrue $field->{hidden});
     # ----
+    
+    # -- New: if column 'documentation' is present, render it via Ext.ux.FieldHelp plugin
+    if($Cnf->{documentation}) {
+      $field->{plugins} ||= [];
+      push @{$field->{plugins}}, 'fieldhelp';
+      $field->{helpText} = $Cnf->{documentation};
+    }
+    # --
 		
 		push @items, $field;
 	}
