@@ -83,6 +83,15 @@ has 'natural_column_order', is => 'ro', isa => 'Bool', default => 1;
 # This only makes sense in the context of a single row view, not a set/grid
 has 'allow_restful_queries', is => 'ro', isa => 'Bool', default => 0;
 
+# Expose the DatStor 'reload_on_save' option so the user can turn it on
+# TODO - this is a stop-gap until the DatStor as a separate module design
+# can be refactored to make it easier to apply store aoptions in general
+has 'reload_on_save', is => 'ro', isa => 'Bool', default => 0;
+
+# Passed into TableSpec objects -- disables the default behaviour which
+# transforms the header of related columns by appending the relationship path
+has 'no_header_transform', is => 'ro', isa => 'Bool', default => 0;
+
 # Generate a param string unique to this module by URL/path. This only needs to be unique
 # among modules whose ->content may be rendered within the same request, which is only
 # being done for good measure
@@ -222,7 +231,8 @@ sub _build_TableSpec {
     name => $table,
     relation_sep => $self->relation_sep,
     ResultSource => $self->ResultSource,
-    include_colspec => $self->include_colspec
+    include_colspec => $self->include_colspec,
+    no_header_transform => $self->no_header_transform
   );
   
   $opt{updatable_colspec} = $self->updatable_colspec if (defined $self->updatable_colspec);
@@ -301,50 +311,6 @@ sub record_pk_cond {
   return \%cond;
 }
 
-# TODO: deprecate/remove in favor of better _ra-rel-mnt_ solution - GitHub Issue #153
-around '_maybe_special_path_redirect' => sub {
-  my ($orig, $self, $opt, @subargs)= @_;
-
-  # This will detach if the special path test matches (original method):
-  $self->$orig($opt, @subargs);
-
-  # Re-test if this is a special path (and redirect) again after stripping
-  # prefixed arguments which correspond to RESTful path patterns, specific to
-  # DbicLnk. This allows relative paths to assets and simplecas, etc, from 
-  # content generated within modules which are loaded in this manner 
-  # (e.g. <module>/item/34/rel/foobar/ and so on)
-  if($self->allow_restful_queries) {
-
-    my $s = sub {
-      my @sargs = @_;
-      # The rel/name form:
-      if($sargs[0] eq 'rel' || $sargs[0] eq 'rs') {
-        shift @sargs;
-        shift @sargs;
-      }
-      $self->$orig(@sargs)
-    };
-
-    # To limit the risk of namespace collisions (since now we're sharing our
-    # namespace with record pk values), require more arguments. This still doesn't
-    # fully eliminate the possibility; if a key/col value matches the pattern like
-    # 'simplecas/<something>/<something>' (with literal '/' chars) then we will
-    # collide and that record path will be unreachable. I consider this risk to
-    # be low enough to live with for now, and its not worth doing further validation
-    # since this test happens on every request (hence we want to keep it lightweight)
-    if (scalar(@subargs) > 2) {
-      # The pk value form (<path>/<pk_value>/...):
-      $s->(@subargs);
-
-      # The name/value form (<path>/<col_name>/<col_value>/...):
-      if(scalar(@subargs) > 3) {
-        shift @subargs;
-        $s->(@subargs);
-      }
-    }
-  }
-};
-
 
 # --- Handle RESTful URLs - convert 'id/1234' into '?___record_pk=1234'
 #has 'restful_record_pk_alias', is => 'ro', isa => 'Str', default => '_id';
@@ -2119,7 +2085,7 @@ before DataStore2_BUILD => sub {
   
   my $store_params = {
     store_autoLoad => 1,
-    reload_on_save => 0,
+    reload_on_save => $self->reload_on_save,
     remoteSort => \1,
     store_fields => \@store_fields
   };
