@@ -192,19 +192,17 @@ Ext.ux.AutoPanel = Ext.extend(Ext.Panel, {
   cmpConfig: {},
   update_cmpConfig: null,
   
-  onAutoLoadFailure: function(el,response) {
-    // --- RapidApp Exceptions are handled in global Ajax handlers:
-    if(
-      response && Ext.isFunction(response.getResponseHeader) &&
-      response.getResponseHeader('X-RapidApp-Exception')
-    ) { return; }
-    // ---
+  errorDataForResponse: function(response) {
+    var opt = { 
+      tabTitle: '<span style="color:gray;">(load failed)</span>',
+      tabIconCls: 'ra-icon-warning' 
+    };
     
     var retry_text = [
      'Please try again later.&nbsp;&nbsp;',
      '<div style=height:20px;"></div>',
      '<span style="font-size:.7em;">',
-     '<i>If you continue to receive this message, please contact your ',
+     '<i style="white-space:normal;">If you continue to receive this message, please contact your ',
      'System Administrator.</i></span>',
      '<div class="retry-foot">',
       '<center>',
@@ -216,21 +214,18 @@ Ext.ux.AutoPanel = Ext.extend(Ext.Panel, {
      '</div>'
     ].join(' ');
     
-    var title = 'Load Request Failed:';
-    var msg = '<div style="padding:10px;font-size:1.3em;color:navy;">&nbsp;&nbsp;' +
+    opt.title = 'Load Request Failed:';
+    opt.msg = '<div style="padding:10px;font-size:1.3em;color:navy;">&nbsp;&nbsp;' +
      response.statusText + 
      '&nbsp;</div>' +
      '<br>' + retry_text;
-    var opt = { 
-      tabTitle: '<span style="color:gray;">(load failed)</span>',
-      tabIconCls: 'ra-icon-warning' 
-    };
+    
     
     // All-purpose timeout message:
     if(response.isTimeout) {
       opt.tabTitle = '<span style="color:gray;">(timed out)</span>';
-      title = 'Load Request Timeout';
-      msg = 'The page/content load request timed out.<br><br>Possible causes:<br>' +
+      opt.title = 'Load Request Timeout';
+      opt.msg = 'The page/content load request timed out.<br><br>Possible causes:<br>' +
        '<ol style="list-style:circle inside;padding:20px;font-size:.8em;color:navy;">' +
        '<li>Connection problem. (check to make sure you can access other sites)</li>' +
        '<li>The server may be responding slowly due to an unusually high load.</li>' +
@@ -238,7 +233,21 @@ Ext.ux.AutoPanel = Ext.extend(Ext.Panel, {
        '</ol>' + retry_text;
     }
     
-    return this.setErrorBody(title,msg,opt);
+    return opt;
+  
+  },
+  
+  onAutoLoadFailure: function(el,response) {
+    // --- RapidApp Exceptions are handled in global Ajax handlers:
+    if(
+      response && Ext.isFunction(response.getResponseHeader) &&
+      response.getResponseHeader('X-RapidApp-Exception')
+    ) { return; }
+    // ---
+    
+    var opt = this.errorDataForResponse(response);
+
+    return this.setErrorBody(opt.title,opt.msg,opt);
   },
 
   // Save the ID of the AutoPanel in the Updater object for referencing if
@@ -463,13 +472,9 @@ Ext.ux.AutoPanel = Ext.extend(Ext.Panel, {
     this.insert(0,conf);
     this.doLayout();
   },
-
-  setErrorBody: function(title,msg,opt) {
-    opt = opt || {};
-    opt = Ext.apply({
-      tabTitle: 'Load Failed',
-      tabIconCls: 'ra-icon-cancel',
-      html: [
+  
+  htmlForError: function(title,msg) {
+    return [
         '<div class="ra-autopanel-error">',
           '<div class="ra-exception-heading">',
             title,
@@ -483,7 +488,15 @@ Ext.ux.AutoPanel = Ext.extend(Ext.Panel, {
           '</div>',
           '<div class="msg">',msg,'</div>',
         '</div>'
-      ].join('')
+      ].join('');
+  },
+
+  setErrorBody: function(title,msg,opt) {
+    opt = opt || {};
+    opt = Ext.apply({
+      tabTitle: 'Load Failed',
+      tabIconCls: 'ra-icon-cancel',
+      html: this.htmlForError(title,msg)
     },opt);
     
     opt.bodyConf = opt.bodyConf || {
@@ -657,7 +670,7 @@ Ext.ux.RapidApp.showAjaxError = function(title,msg,options,data) {
       return Ext.ux.RapidApp.WinFormPost(data.winform);
     }
     else {
-      return Ext.ux.RapidApp.errMsgHandler(title,msg,data.as_text);
+      return Ext.ux.RapidApp.errMsgHandler(title,msg,data.as_text,data.extra_opts);
     }
   
   }
@@ -718,7 +731,26 @@ Ext.ux.RapidApp.ajaxRequestContentType = function(conn,options) {
 
 
 Ext.ux.RapidApp.ajaxException = function(conn,response,options) {
-  if (response && response.getResponseHeader) {
+
+  var opts = options, Cmp = opts && opts.request && opts.request.scope // ref to the store object
+    && opts.request.scope.datastore_plus_plugin // if the store has the DataStorePlus plugin loaded
+    ? opts.request.scope.datastore_plus_plugin.cmp : null;
+
+  if(response && response.isTimeout){
+    var timeout = opts.timeout ? (opts.timeout/1000) : null;
+    timeout = timeout ? timeout : conn.timeout ? (conn.timeout/1000) : null;
+    var msg = timeout ? 'Ajax Request Timed Out (' + timeout + ' seconds).' : 'Ajax Request Timed Out.';
+
+    var title = 'Timeout';
+    Ext.ux.RapidApp.errMsgHandler(title,msg,null,{
+      win_title: response.statusText || 'Ajax Timeout',
+      warn_icon: true,
+      win_width: 350,
+      win_height: 200,
+      smartRenderTo: Cmp
+    });
+  }
+  else if (response && response.getResponseHeader) {
     if(response.getResponseHeader('X-RapidApp-Exception')) {
       // If this is an exception with the X-RapidApp-Exception header,
       // pass it off to the normal check exception logic
@@ -733,7 +765,8 @@ Ext.ux.RapidApp.ajaxException = function(conn,response,options) {
       // this point:
       return Ext.ux.RapidApp.showAjaxError(
         'Ajax Exception - ' + response.statusText + ' (' + response.status + ')',
-        '<pre>' + Ext.util.Format.htmlEncode(response.responseText) + '</pre>'
+        '<pre>' + Ext.util.Format.htmlEncode(response.responseText) + '</pre>',
+        null, { extra_opts: { smartRenderTo: Cmp } }
       );
     }
   }
@@ -756,7 +789,8 @@ Ext.ux.RapidApp.ajaxException = function(conn,response,options) {
       'Ajax Request Failed',
       '<div style="padding:10px;font-size:1.5em;color:navy;">&nbsp;&nbsp;' +
         '<b>' + msg + '</b>' +
-      '&nbsp;</div>'
+      '&nbsp;</div>',
+      null, { extra_opts: { smartRenderTo: Cmp } }
     );
   }
 }
@@ -788,23 +822,6 @@ Ext.Ajax.on('requestcomplete',Ext.ux.RapidApp.ajaxHideGlobalMask,this);
 Ext.Ajax.on('requestexception',Ext.ux.RapidApp.ajaxHideGlobalMask,this);
 
 
-Ext.Ajax.on('requestexception',function(conn,response,options){
-  
-  if(response && response.isTimeout){
-    
-    var timeout = options.timeout ? (options.timeout/1000) : null;
-    timeout = timeout ? timeout : conn.timeout ? (conn.timeout/1000) : null;
-    var msg = timeout ? 'Request Timed Out (' + timeout + ' secs).' : 'Request Timed Out.';
-    
-    Ext.Msg.show({
-      title:'Timeout',
-      msg: msg,
-      icon: Ext.Msg.WARNING,
-      buttons: Ext.Msg.OK
-    });
-  }
-});
-
 
 /* -------------------------------------------------------------------------------------
 /* ------------------------------------------------------------------------------------- 
@@ -842,41 +859,248 @@ Ext.ux.RapidApp.newConn = function(config) {
 /* ------------------------------------------------------------------------------------- */
 
 
-/* This is an experimental function to dynamically scan and convert html
-   elements into AutoPanels based on a special css selector class name
-   and attemping to decode the elements innerHTML as a JSON object to
-   use as 'autoLoad' for the AutoPanel. The function is working as designed
-   and expected, however it is not used anyplace yet, and may prove to
-   not be useful and be removed later. The original thought was to use
-   within normal HTML content, however, without the correct CSS, ExtJS
-   panels/grids don't render correctly, so those cases are now being pursued
-   using iFrames. However, I'm not deleting this yet because it may be
-   helpful later on...                                                        */
-Ext.ux.RapidApp.loadAsyncAutoPanels = function(Element) {
-  Element = Element || Ext.getBody();
-  var nodes = Element.query('.ra-async-autopanel');
+/*  ra-async-box
+
+NEW - general-purpose Ajax content loader, triggered by special CSS class 'ra-async-box'
+
+This is essentially a lighter, stand-alone version of 'AutoPanel' but it is designed
+to load on-the-fly in any tag with the 'ra-async-box' class and a 'src' attibute 
+defined. This is meant to follow the same pattern as iframe, but our use of 'src' is
+a bastardization. The content is designed to load either within another ExtJS component
+or not, and hooks the appropriate resize events in either case. If we're within another
+component, while we do hook its resize event, we do _NOT_ properly participate in its
+layout. We are essentially stand-alone, bound to the original element.
+
+The reason for this is to support more flexibility to load async content without needing
+to setup a full-blown container structure with child items, etc, as is the case with 
+AutoPanel. We may take some of these ideas back to AutoPanel as well
+
+   -- STILL EXPERIMENTAL --   */
+Ext.ux.RapidApp.loadAsyncBoxes = function(Target) {
+  
+  var Element, Container;
+  if(Target && Target instanceof Ext.BoxComponent) {
+    Container = Target;
+    Element = Container.getEl();
+  }
+  else {
+    Element = Target || Ext.getBody();
+  }
+  
+  if(!Element || ! (Element instanceof Ext.Element)) { return; }
+  
+  var nodes = Element.query('.ra-async-box');
   
   Ext.each(nodes,function(dom,index){
-    var el = new Ext.Element(dom);
-    if(el.hasClass('ra-async-autopanel-loaded')) {
-      return;
-    }
-    try {
-      decoded = Ext.decode(el.dom.innerHTML);
-      if(decoded && decoded.url) {
-        el.dom.innerHTML = '';
-        var Cmp = Ext.create({
-          xtype: 'autopanel',
-          autoLoad: decoded,
-          renderTo: el
-        });
-      }
-    }
-    catch(err) {
-      // If the innerHTML was not valid JSON, we will get here.
-      // do nothing - ignore the element
+    var El = new Ext.Element(dom);
+    if(El.hasClass('loaded')) { return; }
+    
+    var src = El.getAttribute('src');
+    if(!src) { return; }
+    
+    // Clear any existing content
+    El.dom.innerHTML = '';
+    
+    // Add the 'loaded' class early to ensure we're only processed once
+    El.addClass('loaded');
+    
+    var loadMask = new Ext.LoadMask(El);
+    loadMask.show();
+    
+    var reloadFn = function() {
+      loadMask.hide();
+      El.removeClass('loaded');
+      El.dom.innerHTML = '';
+      return Ext.ux.RapidApp.loadAsyncBoxes(Target);
     };
-    el.addClass('ra-async-autopanel-loaded');
-  });
-}
+    
+    // Hook to reload on 'ra-autopanel-reloader' clicks, just like AutoPanel
+    if(!El.reloadClickListener) {
+      El.reloadClickListener = function(e,t,o) {
+        var target = e.getTarget(null,null,true);
+        if(target && target.hasClass('ra-autopanel-reloader')) {
+          e.stopEvent(); 
+          reloadFn.call(El);
+        }
+      };
+      El.on('click',El.reloadClickListener,El);
+    }
 
+    var failure = function(response,options) {
+    
+      // re-use markup code from AutoPanel:
+      var opt  = Ext.ux.AutoPanel.prototype.errorDataForResponse(response);
+      var html = Ext.ux.AutoPanel.prototype.htmlForError(opt.title,opt.msg);
+      
+      var size = El.getSize();
+      
+      var div = document.createElement('div');
+      var errEl = new Ext.Element(div);
+      
+      var height = size.height - 18;
+      var width  = size.width  - 18;
+      if(width  < 80) { width  = 80; }
+      if(height < 30) { height = 30; }
+      
+      errEl.setSize(width,height);
+
+      errEl.setStyle({ 
+        'position'    : 'relative', 
+        'overflow'    : 'auto',
+        'white-space' : 'nowrap'
+      });
+      
+      errEl.dom.innerHTML = html;
+      
+      El.dom.innerHTML = '';
+      El.appendChild(errEl); // must already be appened before we call boxWrap()
+      errEl.boxWrap(); // apply same styles as panel 'frame' option
+      
+      loadMask.hide();
+
+    };
+    
+    var success = function(response,options) {
+      var ct = response.getResponseHeader('Content-Type');
+      if(ct) { ct = ct.split(';')[0]; }
+      
+      // The 'text/javascript' content type means this is a ExtJS config
+      if(ct && ct == 'text/javascript') {
+
+        var cnf = Ext.decode(response.responseText);
+        
+        // Our height and width is bound to the existing size of the element (if it has them)
+        var size = El.getSize();
+        if(size.height) { cnf.height = size.height; }
+        if(size.width)  { cnf.width  = size.width;  }
+        
+        loadMask.hide();
+        var Cmp = Ext.create(cnf);
+        
+        Cmp.reload = reloadFn;
+        
+        // --
+        // resizeFn: Calls itself recursively up to 20 times until the height is greater than 0.
+        // This gives the dom extra time to finish updating itself for when the ra-async-box has
+        // its size determined by its content (which we're setting). Once the size has updated
+        // and there is a positive height, it will continue to call itself until both the height
+        // and width are unchanged for three iterations (80 ms apart). This is a general-purpose
+        // handler for dynamic sizing, with a reletively small footprint. There is no native way
+        // to handle element resize detection w/o setting up some kind of polling/timer, so this
+        // is actually less hackish than it might appear on first glance...
+        var resizeFn = function(){
+          var _reSize, lastSize;
+          _reSize = function(ttl) {
+            ttl = typeof ttl == "undefined" ? 20 : ttl;
+            if(ttl < 0) {  return;  }
+            else        {  ttl--;   }
+
+            var size = El.getSize();
+
+            if(size.height == 0 && ttl >= 0) {
+              var delay = 15 + ((20-ttl)*3);
+              _reSize.defer(delay,this,[ttl]);
+            }
+            else {
+              Cmp.setSize.call(Cmp,size.width,size.height);
+              // Re-apply the element height to prevent recursive scenario where dynamic heights
+              // cause a infinite loop progressing stepping the height, if the component setSize
+              // changed the element height -- TODO: there may be more cases yet to handle...
+              El.setHeight(size.height);
+              if(lastSize) {
+                // Reset if the size has changed:
+                if(lastSize.height != size.height || lastSize.width != size.width) {
+                  lastSize = null;
+                }
+              }
+              // call ourselves again until the size stays the same, thrice more in a row
+              if(!lastSize) {
+                lastSize = size;
+                ttl = 2;
+              }
+              _reSize.defer(80,this,[ttl]);
+            }
+          }
+          _reSize();
+        };
+        
+        // Save a reference to the resizeFn within the DOM object so it can be found again
+        // later by the asyncBoxesOnResize listener, below - but NOT found if the element
+        // is removed or no longer contained within the DOM (.
+        dom._onAsyncBoxResize = resizeFn;
+        // --
+        
+        if(Container) {
+          // If we're within another component/container, we'll hook into its
+          // 'resize' event to trigger recalculation of our size. This only
+          // matters when the element's size changes, if it can, such as with
+          // absolute positioning or when a width percent value is supplied, etc
+          // --
+          // NEW: hook using a global function only ONCE - this prevents duplicate listeners
+          // from being attached to the same componenet mutliple times, which can 
+          // happen when AppDV templates, or other dynamic content include ra-async-box
+          // that is updated or replaced via refresh of other mechanism. This listener
+          // is applied exactly 1 time per unique Container object, and uses the DOM
+          // to scan and find the ra-async-box elements again, and call their resize
+          // listeners (dom._onAsyncBoxResize, as set above). This is yet another example
+          // of a bastardized replacement for real layout manager
+          if(! Container._asyncBoxResizeListener) {
+            Container._asyncBoxResizeListener = Ext.ux.RapidApp.asyncBoxesOnResize;
+            Container.on('resize',Container._asyncBoxResizeListener,Container);
+          }
+          
+          // Set our ownerCt, even though we're not proper participants in the layout
+          Cmp.ownerCt = Container;
+        }
+        else {
+          // If we're not within a container, hook the raw browser resize
+          // TODO: should we also setup this case to hook only once?
+          Ext.EventManager.onWindowResize(resizeFn, Cmp,{delay:300});
+        }
+
+        // Trigger resize after render so any dynamic sizes can
+        // update after the new content is present:
+        Cmp.on('afterrender',resizeFn,Cmp);//,{delay:50});
+
+        Cmp.render(El);
+        if(Ext.isFunction(Cmp.doLayout)) {
+          Cmp.doLayout();
+        }
+      }
+      else {
+        // If we're here it means the returned content is not module config.
+        // For now, we simply inline the raw text
+        loadMask.hide();
+        El.dom.innerHTML = response.responseText;
+      }
+    };
+
+    Ext.Ajax.request({
+      url     : src,
+      success : success,
+      failure : failure
+    });
+  },this);
+};
+// This is the global async resize listener function which we attach to 
+Ext.ux.RapidApp.asyncBoxesOnResize = function(Target) {
+  var args = arguments;
+  var Element, Container;
+  if(Target && Target instanceof Ext.BoxComponent) {
+    Container = Target;
+    Element = Container.getEl();
+  }
+  else {
+    Element = Target || Ext.getBody();
+  }
+  
+  if(!Element || ! (Element instanceof Ext.Element)) { return; }
+  
+  var nodes = Element.query('.ra-async-box');
+  
+  Ext.each(nodes,function(dom,index){
+    if (dom._onAsyncBoxResize) {
+      dom._onAsyncBoxResize.apply(Target,args);
+    }
+  },this);
+};
